#Default template
def template_cp():
    template = """#include <bits/stdc++.h>
#include <iostream> 

using namespace std; 

int main() 
{ 
    ios_base::sync_with_stdio(false); 
    cin.tie(NULL); 

    /* This is needed as most contests use this format */
    #ifndef ONLINE_JUDGE  
        freopen("input.txt", "r", stdin);  
        freopen("output.txt", "w", stdout); 
    #endif 

    //Code

    cerr << "time taken : " << (float)clock() / CLOCKS_PER_SEC << " secs" << endl; //Optional
    return 0; 
} """

    return template

def get_filename():
    fileNames = ['A.cpp','B.cpp','C.cpp','D.cpp','E.cpp','F.cpp']
    return fileNames

def get_fn_beginner():
    fileNames = ['A.cpp','B.cpp','C.cpp']
    return fileNames

# Template 2
def template_agg():
    temp = """#pragma GCC optimize("Ofast")
#pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx,avx,avx2,fma")
#pragma GCC optimize("unroll-loops")
#include <bits/stdc++.h> 
#include <complex>
#include <queue>
#include <set>
#include <unordered_set>
#include <list>
#include <chrono>
#include <random>
#include <iostream>
#include <algorithm>
#include <cmath>
#include <string>
#include <vector>
#include <map>
#include <unordered_map>
#include <stack>
#include <iomanip>
#include <fstream>

using namespace std;

typedef long long ll;
typedef long double ld;
typedef pair<int,int> p32;
typedef pair<ll,ll> p64;
typedef pair<double,double> pdd;
typedef vector<ll> v64;
typedef vector<int> v32;
typedef vector<vector<int> > vv32;
typedef vector<vector<ll> > vv64;
typedef vector<vector<p64> > vvp64;
typedef vector<p64> vp64;
typedef vector<p32> vp32;
ll MOD = 998244353;
double eps = 1e-12;
#define forn(i,e) for(ll i = 0; i < e; i++)
#define forsn(i,s,e) for(ll i = s; i < e; i++)
#define rforn(i,s) for(ll i = s; i >= 0; i--)
#define rforsn(i,s,e) for(ll i = s; i >= e; i--)
#define dbg(x) cout<<#x<<" = "<<x<<ln
#define mp make_pair
#define pb push_back
#define fi first
#define se second
#define INF 2e18
#define fast_cin() ios_base::sync_with_stdio(false); cin.tie(NULL); cout.tie(NULL)
#define all(x) (x).begin(), (x).end()
#define sz(x) ((ll)(x).size())


int main()
{
	fast_cin();
    #ifndef ONLINE_JUDGE  
    freopen("in.in", "r", stdin);  
    freopen("out.out", "w", stdout); 
    //Edit names accordingly
    #endif 

	//Code

	return 0;
}
"""
    return temp


#!usr/bin/python3
import sys
import os
from clint.textui import colored
from codeit.codeitHelp import help
from codeit.codeitInit import init, init_agg, create_only_files
from codeit.codeitMeta import template_agg, template_cp, get_filename, get_fn_beginner

def main():
    if len(sys.argv) < 2:
        help()

    else:
        countArg = 0

        for arg in sys.argv:
            countArg+=1

            if arg == "-i":
                if sys.argv[countArg] == '-n':
                    fileName = sys.argv[countArg+1]
                    template = template_agg()
                    init_single_file(f'{fileName}.cpp', template)
                    print(colored.yellow(f'Created {fileName}.cpp'))
                    break
                elif sys.argv[countArg] == '-b':
                    if sys.argv[countArg+1] == '-ne':
                        contestName = sys.argv[countArg+2]
                        fileNames = get_fn_beginner()
                        init(contestName, fileNames)
                    elif sys.argv[countArg+1] == '-t2':
                        contestName = sys.argv[countArg+2]
                        fileNames = get_fn_beginner()
                        init_agg(contestName, fileNames)
                elif sys.argv[countArg] == '-t2':
                    contestName = sys.argv[countArg+1]
                    fileNames = get_filename()
                    init_agg(contestName, fileNames)
                else:
                    contestName = sys.argv[countArg]
                    fileNames = get_filename()
                    init(contestName, fileNames)
            elif arg == "-f":
                contestName = sys.argv[countArg]
                fileNames = get_filename()
                create_only_files(contestName, fileNames)

            elif arg == "-v":
                print(colored.magenta('CODEIt v1.0.3 (c)2020 - 2021, @alphaX86'))

            elif arg == "-h":
                help()


def init_single_file(filename, template='\n'):
  full_filename = os.path.join(os.getcwd(), filename)
  with open(full_filename, 'w+') as f:
    f.write(template)



import os
from clint.textui import colored
from codeit.codeitMeta import template_cp, template_agg

def write_to_file(filename, text, contestName=None):
  full_filename = os.path.join(os.getcwd(), filename)
  if contestName is not None:
    full_filename = os.path.join(os.getcwd(), contestName, filename)
  with open(full_filename, 'w+') as f:
    f.write(text)

def init(contestName,fileNames):
  # create a directory with contest name
  try:
    print(colored.blue('Making files and folders for ' + colored.magenta(contestName)))
    os.makedirs(os.path.join(os.getcwd(), contestName))
  except OSError:
    print(colored.red("Failed! This directory cannot be created as it exists."))
  else:
    print(colored.yellow('Directory is made'))
      # create files for contest (should be 6 cpp files)
    for files in range(len(fileNames)):
      write_to_file(fileNames[files], template_cp(), contestName)
    # create input file
    write_to_file('input.txt', '', contestName)
    write_to_file('output.txt', '', contestName)
    print(colored.green('Files have been created. Happy Coding!'))


# For template 2
def init_agg(contestName, fileNames):
  try:
    print(colored.blue('Making files and folders for ' + colored.magenta(contestName)))
    os.makedirs(os.path.join(os.getcwd(), contestName))
  except OSError:
    print(colored.red("Failed! This directory cannot be created as it exists."))
  else:
    print(colored.yellow('Directory is made'))
      # create files for contest (should be 6 cpp files)
    for files in range(len(fileNames)):
      write_to_file(fileNames[files], template_agg(), contestName)
    # create input file
    write_to_file('input.txt', '', contestName)
    write_to_file('output.txt', '', contestName)
    print(colored.green('Files have been created. Happy Coding!'))

def create_only_files(contestName, fileNames):
  try:
    print(colored.blue('Making files for ' + colored.magenta(contestName)))
    os.makedirs(os.path.join(os.getcwd(), contestName))
  except OSError:
    print(colored.red("Failed! This directory cannot be created as it exists."))
  else:
    print(colored.yellow('Directory is made'))
      # create files for contest (should be 6 cpp files)
    for files in range(len(fileNames)):
      write_to_file(fileNames[files], template_agg(), contestName)

    print(colored.green('Files have been created. Happy Coding!'))



from clint.textui import colored


def help():
    function = {"  -h ": " To display help menu.",
                "  -i <contest> ": " To initialize a contest directory.",
                "  -f ": " To create only files in a directory.", 
                "  -i -b <contest> ": " To initialize a contest directory for practice and beginner level.",
                "  -i <args> -t2 <contest> ": " To initialize a contest directory and use 2nd template.",
                "  -i -n <file> ": " To initialize only a single file.",
                "  -v ": " To print version number."}

    print('\n')

    print(colored.red("""  ██████╗  ██████╗  ██████╗  ███████╗ ██╗ ████████╗
 ██╔════╝ ██╔═══██╗ ██╔══██╗ ██╔════╝ ██║ ╚══██╔══╝
 ██║      ██║   ██║ ██║  ██║ █████╗   ██║    ██║   
 ██║      ██║   ██║ ██║  ██║ ██╔══╝   ██║    ██║   
 ╚██████╗ ╚██████╔╝ ██████╔╝ ███████╗ ██║    ██║   
  ╚═════╝  ╚═════╝  ╚═════╝  ╚══════╝ ╚═╝    ╚═╝   """))

    print(colored.cyan(
        "\n The CLI Script tool to help you initialize CPP files for any contest."))

    print(colored.red('\n Command: '))
    print(colored.cyan("  codeit <args> <filename/contestname>"))

    print(colored.red('\n Args list: '))
    for arg, func in function.items():
        print(colored.yellow(arg) + '-'*(30-len(arg)) + '>' + colored.cyan(func))
    print('\n')



from setuptools import setup,find_packages

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
  name='cxit',
  packages = find_packages(),
  version='1.0.3',
  author='Aadhitya A',
  author_email='aadhitya864@gmail.com',
  description = 'A CLI tool to create CPP files for any contest',
  long_description = long_description,
  long_description_content_type="text/markdown",
  license = 'MIT License',
  py_modules=['codeit'],
  url="https://github.com/Arch2x/codeit",
  classifiers=(
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7'
    ),
  python_requires='>=3.5',
  include_package_data = True,
  install_requires=[
    'clint'
  ],
  entry_points={
    'console_scripts': [
      'codeit = codeit.codeit:main'
    ]
  }
)
